import { QueryHandler } from '@nestjs/cqrs';
import { AuthRepository } from '../../adapters/secondaries/auth.repository';
import { ValidateQuery } from '../../queries/validate.query';
import { Auth } from '../entities/auth';
import * as bcrypt from 'bcrypt';
import { NotFoundException, UnauthorizedException } from '@nestjs/common';

@QueryHandler(ValidateQuery)
export class ValidateUseCase {
  constructor(private readonly _authRepository: AuthRepository) {}

  async execute(validate: ValidateQuery): Promise<Auth> {
    const auth = await this._authRepository.findOne({
      username: validate.username,
    });
    if (auth) {
      const isMatch = await bcrypt.compare(validate.password, auth.password);
      if (isMatch) return auth;
      throw new UnauthorizedException();
    }
    throw new NotFoundException();
  }
}
